@@ -1,6 +1,6 @@
 package MARC::Moose::Parser::Marcxml;
 # ABSTRACT: Parser for MARXML records
-$MARC::Moose::Parser::Marcxml::VERSION = '1.0.25';
+$MARC::Moose::Parser::Marcxml::VERSION = '1.0.26';
 use Moose;
 
 extends 'MARC::Moose::Parser';
@@ -44,10 +44,12 @@ override 'parse' => sub {
                 s/<\/subfield//;
                 push @subf, [ $letter => $_ ];
             }
+            $ind1 = ' ' unless defined($ind1);
+            $ind2 = ' ' unless defined($ind2);
             push @fields, MARC::Moose::Field::Std->new(
                 tag => $tag,
-                ind1 => $ind1 || ' ',
-                ind2 => $ind2 || ' ',
+                ind1 => $ind1,
+                ind2 => $ind2,
                 subf => \@subf );
             shift @parts;
             next;
@@ -75,7 +77,7 @@ MARC::Moose::Parser::Marcxml - Parser for MARXML records
 
 =head1 VERSION
 
-version 1.0.25
+version 1.0.26
 
 =head1 DESCRIPTION
 
