@@ -1,6 +1,6 @@
 package MARC::Moose::Parser::MarcxmlSaxSimple;
 # ABSTRACT: Parser for MARXML records using SAX::Simple parser
-$MARC::Moose::Parser::MarcxmlSaxSimple::VERSION = '1.0.25';
+$MARC::Moose::Parser::MarcxmlSaxSimple::VERSION = '1.0.26';
 use Moose;
 
 extends 'MARC::Moose::Parser';
@@ -29,8 +29,8 @@ override 'parse' => sub {
         my @sf = map { [ $_->{code}, $_->{content} ] }  @{$_->{subfield}};
         MARC::Moose::Field::Std->new(
             tag  => $_->{tag},
-            ind1 => $_->{ind1},
-            ind2 => $_->{ind2},
+            ind1 => defined($_->{ind1}) ? $_->{ind1} : ' ',
+            ind2 => defined($_->{ind2}) ? $_->{ind2} : ' ',
             subf => \@sf,
         ); 
     } @{$ref->{datafield}};
@@ -55,7 +55,7 @@ MARC::Moose::Parser::MarcxmlSaxSimple - Parser for MARXML records using SAX::Sim
 
 =head1 VERSION
 
-version 1.0.25
+version 1.0.26
 
 =head1 SEE ALSO
 
